from functools import wraps

import sniffio


def maybe_sync(m):
    @wraps(m)
    def _wrapper(*args, **kwargs):
        coro = m(*args, **kwargs)
        try:
            sniffio.current_async_library()
        except sniffio.AsyncLibraryNotFoundError:
            pass
        else:
            return coro

        result = None
        try:
            while True:
                result = coro.send(result)
        except StopIteration as si:
            return si.value

    return _wrapper



"""
Define the ArboristClient class for interfacing with the arborist service for
authz.
"""

import httpx

try:
    import urllib.parse as urllib
except ImportError:
    import urllib

from .base import BaseArboristClient


class SyncClient(httpx.Client):
    async def __aenter__(self):
        return self.__enter__()

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        self.__exit__(exc_type, exc_val, exc_tb)

    async def request(self, *args, **kwargs):
        return super().request(*args, **kwargs)


class ArboristClient(BaseArboristClient):
    """
    A singleton class for interfacing with the authz engine, "arborist".
    """

    client_cls = SyncClient

    def _is_async(self):
        return False



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['gen3authz', 'gen3authz.client', 'gen3authz.client.arborist']

package_data = \
{'': ['*']}

install_requires = \
['backoff>=1.6,<2.0',
 'cdiserrors<2.0.0',
 'httpx>=0.20.0,<1.0.0',
 'six>=1.16.0,<2.0.0']

extras_require = \
{':python_version < "3.7"': ['contextvars>=2.4,<3.0']}

setup_kwargs = {
    'name': 'gen3authz',
    'version': '1.5.1',
    'description': 'Gen3 authz client',
    'long_description': None,
    'author': 'CTDS UChicago',
    'author_email': 'cdis@uchicago.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
